pub trait Request: Serialize + DeserializeOwned {
type Response: Serialize + DeserializeOwned;
type Error: ApiError;
const PATH: &'static str;
const METHOD: Method;
const SIZE_LIMIT: usize = 4096;
const TIMEOUT: usize = 60;
const HEADERS: &'static [&'static str] = _;
}Expand description
Basic request definition.
The request will be serialized and deserialized via Json to ease updating structures without breaking backwards compatibility.
Required Associated Constants
Provided Associated Constants
const SIZE_LIMIT: usize = 4096
const TIMEOUT: usize = 60
const HEADERS: &'static [&'static str] = _
Required Associated Types
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".